You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@orc.apache.org by do...@apache.org on 2022/07/07 16:41:50 UTC

[orc] branch branch-1.8 updated (d9378575d -> 279b60f67)

This is an automated email from the ASF dual-hosted git repository.

dongjoon pushed a change to branch branch-1.8
in repository https://gitbox.apache.org/repos/asf/orc.git


    from d9378575d ORC-1206: Bump netty-all from 4.1.68.Final to 4.1.78.Final (#1163)
     new e044fab4f ORC-1187: Use `main` instead of `master` in `merge_orc_pr.py`
     new 279b60f67 ORC-1197: Bump mockito.version from 4.6.0 to 4.6.1 (#1151)

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 dev/merge_orc_pr.py | 4 ++--
 java/pom.xml        | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)


[orc] 01/02: ORC-1187: Use `main` instead of `master` in `merge_orc_pr.py`

Posted by do...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

dongjoon pushed a commit to branch branch-1.8
in repository https://gitbox.apache.org/repos/asf/orc.git

commit e044fab4fe15b1670a3a01762aec7d8c453424e1
Author: Dongjoon Hyun <do...@apache.org>
AuthorDate: Tue May 24 09:27:16 2022 -0700

    ORC-1187: Use `main` instead of `master` in `merge_orc_pr.py`
    
    ### What changes were proposed in this pull request?
    
    This PR aims to revise `merge_orc_pr.py` to use `main` branch instead of `master`.
    
    ### Why are the changes needed?
    
    This is needed when the script update Apache ORC JIRA.
    
    ### How was this patch tested?
    
    Manual test.
    
    Closes #1139 from dongjoon-hyun/ORC-1187.
    
    Authored-by: Dongjoon Hyun <do...@apache.org>
    Signed-off-by: Dongjoon Hyun <do...@apache.org>
    (cherry picked from commit 8f038a068c61cdac72c4c58ad023ad3c4ab10e38)
    Signed-off-by: Dongjoon Hyun <do...@apache.org>
---
 dev/merge_orc_pr.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/java/pom.xml b/java/pom.xml
index 68c45f350..cb2113560 100644
--- a/java/pom.xml
+++ b/java/pom.xml
@@ -82,7 +82,7 @@
     <protoc.artifact>com.google.protobuf:protoc:2.5.0</protoc.artifact>
     <surefire.version>3.0.0-M5</surefire.version>
     <junit.version>5.8.2</junit.version>
-    <mockito.version>4.6.0</mockito.version>
+    <mockito.version>4.6.1</mockito.version>
     <checkstyle.version>10.3</checkstyle.version>
   </properties>
diff --git a/dev/merge_orc_pr.py b/dev/merge_orc_pr.py
index 4917916d3..6aec3c3cd 100755
--- a/dev/merge_orc_pr.py
+++ b/dev/merge_orc_pr.py
@@ -237,7 +237,7 @@ def cherry_pick(pr_num, merge_hash, default_branch):
 
 def fix_version_from_branch(branch, versions):
     # Note: Assumes this is a sorted (newest->oldest) list of un-released versions
-    if branch == "master":
+    if branch == "main":
         return versions[0]
     else:
         branch_ver = branch.replace("branch-", "")
@@ -288,7 +288,7 @@ def resolve_jira_issue(merge_branches, comment, default_jira_id=""):
     )
     for v in default_fix_versions:
         # Handles the case where we have forked a release branch but not yet made the release.
         # In this case, if the PR is committed to the master branch and the release branch, we
         # only consider the release branch to be the fix version. E.g. it is not valid to have
         # both 1.1.0 and 1.0.0 as fix versions.
         (major, minor, patch) = v.split(".")


[orc] 02/02: ORC-1197: Bump mockito.version from 4.6.0 to 4.6.1 (#1151)

Posted by do...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

dongjoon pushed a commit to branch branch-1.8
in repository https://gitbox.apache.org/repos/asf/orc.git

commit 279b60f67c7316fc6c77c4b9bb4d52ce485a6c99
Author: dependabot[bot] <49...@users.noreply.github.com>
AuthorDate: Tue Jun 7 12:14:08 2022 -0700

    ORC-1197: Bump mockito.version from 4.6.0 to 4.6.1 (#1151)
    
    Bumps `mockito.version` from 4.6.0 to 4.6.1.
    
    Updates `mockito-core` from 4.6.0 to 4.6.1
    - [Release notes](https://github.com/mockito/mockito/releases)
    - [Commits](https://github.com/mockito/mockito/compare/v4.6.0...v4.6.1)
    
    Updates `mockito-junit-jupiter` from 4.6.0 to 4.6.1
    - [Release notes](https://github.com/mockito/mockito/releases)
    - [Commits](https://github.com/mockito/mockito/compare/v4.6.0...v4.6.1)
    
    ---
    updated-dependencies:
    - dependency-name: org.mockito:mockito-core
      dependency-type: direct:production
      update-type: version-update:semver-patch
    - dependency-name: org.mockito:mockito-junit-jupiter
      dependency-type: direct:production
      update-type: version-update:semver-patch
    ...
    
    Signed-off-by: dependabot[bot] <su...@github.com>
    
    Co-authored-by: dependabot[bot] <49...@users.noreply.github.com>
    (cherry picked from commit e97de6d074a81bce4476ec1df1559abec06ac339)
    Signed-off-by: Dongjoon Hyun <do...@apache.org>
---
 java/pom.xml | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
@@ -288,7 +288,7 @@ def resolve_jira_issue(merge_branches, comment, default_jira_id=""):
     for v in default_fix_versions:
         # Handles the case where we have forked a release branch but not yet made the release.
-        # In this case, if the PR is committed to the master branch and the release branch, we
+        # In this case, if the PR is committed to the main branch and the release branch, we
         # only consider the release branch to be the fix version. E.g. it is not valid to have
         # both 1.1.0 and 1.0.0 as fix versions.
